==> openshift-model-operatorhub-5.12.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/PackageManifestBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PackageManifestBuilder extends io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestFluentImpl<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifest,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestBuilder>{
  public PackageManifestBuilder() {
    this(false);
  }
  public PackageManifestBuilder(java.lang.Boolean validationEnabled) {
    this(new PackageManifest(), validationEnabled);
  }
  public PackageManifestBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestFluent<?> fluent) {
    this(fluent, false);
  }
  public PackageManifestBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PackageManifest(), validationEnabled);
  }
  public PackageManifestBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifest instance) {
    this(fluent, instance, false);
  }
  public PackageManifestBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifest instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PackageManifestBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifest instance) {
    this(instance,false);
  }
  public PackageManifestBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifest instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifest build() {
    PackageManifest buildable = new PackageManifest(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PackageManifestBuilder that = (PackageManifestBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.3.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/PackageManifestBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PackageManifestBuilder extends PackageManifestFluentImpl<PackageManifestBuilder> implements VisitableBuilder<PackageManifest,PackageManifestBuilder>{
  public PackageManifestBuilder() {
    this(false);
  }
  public PackageManifestBuilder(Boolean validationEnabled) {
    this(new PackageManifest(), validationEnabled);
  }
  public PackageManifestBuilder(PackageManifestFluent<?> fluent) {
    this(fluent, false);
  }
  public PackageManifestBuilder(PackageManifestFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PackageManifest(), validationEnabled);
  }
  public PackageManifestBuilder(PackageManifestFluent<?> fluent,PackageManifest instance) {
    this(fluent, instance, false);
  }
  public PackageManifestBuilder(PackageManifestFluent<?> fluent,PackageManifest instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PackageManifestBuilder(PackageManifest instance) {
    this(instance,false);
  }
  public PackageManifestBuilder(PackageManifest instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  PackageManifestFluent<?> fluent;
  Boolean validationEnabled;
  public PackageManifest build() {
    PackageManifest buildable = new PackageManifest(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
